@@ -13,12 +13,13 @@
 #endif
 
 #include "dlg_setup_newuser_p.h"
-#include "dlg_usertype_pagedefault_l.h"
-#include "dlg_usertype_page_be.h"
-#include "i18n_l.h"
+
+#include "aqbanking/dialogs/dlg_usertype_pagedefault_l.h"
+#include "aqbanking/dialogs/dlg_usertype_page_be.h"
+#include "aqbanking/i18n_l.h"
+#include "aqbanking/backendsupport/provider_be.h"
 
 #include <aqbanking/banking_be.h>
-#include <aqbanking/provider_be.h>
 
 #include <gwenhywfar/gwenhywfar.h>
 #include <gwenhywfar/misc.h>
@@ -45,7 +46,8 @@ GWEN_INHERIT(GWEN_DIALOG, AB_SETUP_NEWUSER_DIALOG)
 
 
 
-GWEN_DIALOG *AB_SetupNewUserDialog_new(AB_BANKING *ab) {
+GWEN_DIALOG *AB_SetupNewUserDialog_new(AB_BANKING *ab)
+{
   GWEN_DIALOG *dlg;
   AB_SETUP_NEWUSER_DIALOG *xdlg;
   GWEN_BUFFER *fbuf;
@@ -58,7 +60,7 @@ GWEN_DIALOG *AB_SetupNewUserDialog_new(AB_BANKING *ab) {
   dlg=GWEN_Dialog_new("ab_setup_newuser");
   GWEN_NEW_OBJECT(AB_SETUP_NEWUSER_DIALOG, xdlg);
   GWEN_INHERIT_SETDATA(GWEN_DIALOG, AB_SETUP_NEWUSER_DIALOG, dlg, xdlg,
-		       AB_SetupNewUserDialog_FreeData);
+                       AB_SetupNewUserDialog_FreeData);
   GWEN_Dialog_SetSignalHandler(dlg, AB_SetupNewUserDialog_SignalHandler);
 
   xdlg->backendDialogs=GWEN_Dialog_List2_new();
@@ -67,9 +69,9 @@ GWEN_DIALOG *AB_SetupNewUserDialog_new(AB_BANKING *ab) {
 
   /* get path of dialog description file */
   fbuf=GWEN_Buffer_new(0, 256, 0, 1);
-  rv=GWEN_PathManager_FindFile(GWEN_PM_LIBNAME, GWEN_PM_SYSDATADIR,
-			       "aqbanking/dialogs/dlg_setup_newuser.dlg",
-			       fbuf);
+  rv=GWEN_PathManager_FindFile(AB_PM_LIBNAME, AB_PM_DATADIR,
+                               "aqbanking/dialogs/dlg_setup_newuser.dlg",
+                               fbuf);
   if (rv<0) {
     DBG_INFO(AQBANKING_LOGDOMAIN, "Dialog description file not found (%d).", rv);
     GWEN_Buffer_free(fbuf);
@@ -80,8 +82,8 @@ GWEN_DIALOG *AB_SetupNewUserDialog_new(AB_BANKING *ab) {
   /* read XML file, extend it */
   n=GWEN_XMLNode_new(GWEN_XMLNodeTypeTag, "root");
   rv=GWEN_XML_ReadFile(n, GWEN_Buffer_GetStart(fbuf),
-		       GWEN_XML_FLAGS_DEFAULT |
-		       GWEN_XML_FLAGS_HANDLE_HEADERS);
+                       GWEN_XML_FLAGS_DEFAULT |
+                       GWEN_XML_FLAGS_HANDLE_HEADERS);
   if (rv<0) {
     DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
     GWEN_XMLNode_free(n);
@@ -111,66 +113,68 @@ GWEN_DIALOG *AB_SetupNewUserDialog_new(AB_BANKING *ab) {
     subDialogs=GWEN_Dialog_List_new();
     if (nBackendRadioWidget) {
       GWEN_PLUGIN_DESCRIPTION_LIST2_ITERATOR *pit;
-  
+
       pit=GWEN_PluginDescription_List2_First(providers);
       if (pit) {
-	GWEN_PLUGIN_DESCRIPTION *pd;
-  
-	pd=GWEN_PluginDescription_List2Iterator_Data(pit);
-	while(pd) {
-	  const char *name;
-  
-	  name=GWEN_PluginDescription_GetName(pd);
-	  if (name && *name) {
-	    AB_PROVIDER *pro;
+        GWEN_PLUGIN_DESCRIPTION *pd;
 
-	    pro=AB_Banking_GetProvider(ab, name);
-	    if (pro) {
-	      GWEN_DIALOG *cdlg;
-	      GWEN_BUFFER *tbuf;
-	      GWEN_XMLNODE *wn;
-	      const char *s;
+        pd=GWEN_PluginDescription_List2Iterator_Data(pit);
+        while (pd) {
+          const char *name;
 
-	      if (AB_Provider_GetFlags(pro) & AB_PROVIDER_FLAGS_HAS_USERTYPE_DIALOG) {
-		cdlg=AB_ProviderGetUserTypeDialog(pro);
-		if (cdlg==NULL) {
-		  DBG_WARN(AQBANKING_LOGDOMAIN, "Backend [%s] does not return a userType dialog, using default", name);
-		  cdlg=AB_UserTypePageDefaultDialog_new(ab);
-		}
-	      }
-	      else
-		cdlg=AB_UserTypePageDefaultDialog_new(ab);
+          name=GWEN_PluginDescription_GetName(pd);
+          if (name && *name) {
+            AB_PROVIDER *pro;
 
-	      tbuf=GWEN_Buffer_new(0, 256, 0, 1);
-	      GWEN_Buffer_AppendString(tbuf, "backend_");
-	      GWEN_Buffer_AppendString(tbuf, name);
-	      GWEN_Buffer_AppendString(tbuf, "_radio");
-    
-	      wn=GWEN_XMLNode_new(GWEN_XMLNodeTypeTag, "widget");
-	      GWEN_XMLNode_SetProperty(wn, "type", "radioButton");
-	      GWEN_XMLNode_SetProperty(wn, "name", GWEN_Buffer_GetStart(tbuf));
-	      GWEN_StringList_AppendString(xdlg->backendRadioNames, GWEN_Buffer_GetStart(tbuf), 0, 0);
-	      GWEN_StringList_AppendString(xdlg->backendNames, name, 0, 0);
-    
-	      s=GWEN_PluginDescription_GetShortDescr(pd);
-	      if (!(s && *s))
-		s=name;
-	      GWEN_XMLNode_SetProperty(wn, "text", I18N(s));
-    
-	      GWEN_XMLNode_SetProperty(wn, "groupId", "999999");
-	      GWEN_XMLNode_SetProperty(wn, "flags", "fillX justifyLeft");
-    
-	      GWEN_XMLNode_AddChild(nBackendRadioWidget, wn);
-	      GWEN_Dialog_List_Add(cdlg, subDialogs);
-	    }
-	    else {
-	      DBG_ERROR(AQBANKING_LOGDOMAIN, "Could not activate backend [%s]", name);
-	    }
-	  }
-  
-	  pd=GWEN_PluginDescription_List2Iterator_Next(pit);
-	}
-	GWEN_PluginDescription_List2Iterator_free(pit);
+            pro=AB_Banking_BeginUseProvider(ab, name);
+            if (pro) {
+              GWEN_DIALOG *cdlg;
+              GWEN_BUFFER *tbuf;
+              GWEN_XMLNODE *wn;
+              const char *s;
+
+              if (AB_Provider_GetFlags(pro) & AB_PROVIDER_FLAGS_HAS_USERTYPE_DIALOG) {
+                cdlg=AB_Provider_GetUserTypeDialog(pro);
+                if (cdlg==NULL) {
+                  DBG_WARN(AQBANKING_LOGDOMAIN, "Backend [%s] does not return a userType dialog, using default", name);
+                  cdlg=AB_UserTypePageDefaultDialog_new(ab);
+                }
+              }
+              else
+                cdlg=AB_UserTypePageDefaultDialog_new(ab);
+
+              tbuf=GWEN_Buffer_new(0, 256, 0, 1);
+              GWEN_Buffer_AppendString(tbuf, "backend_");
+              GWEN_Buffer_AppendString(tbuf, name);
+              GWEN_Buffer_AppendString(tbuf, "_radio");
+
+              wn=GWEN_XMLNode_new(GWEN_XMLNodeTypeTag, "widget");
+              GWEN_XMLNode_SetProperty(wn, "type", "radioButton");
+              GWEN_XMLNode_SetProperty(wn, "name", GWEN_Buffer_GetStart(tbuf));
+              GWEN_StringList_AppendString(xdlg->backendRadioNames, GWEN_Buffer_GetStart(tbuf), 0, 0);
+              GWEN_StringList_AppendString(xdlg->backendNames, name, 0, 0);
+
+              s=GWEN_PluginDescription_GetShortDescr(pd);
+              if (!(s && *s))
+                s=name;
+              GWEN_XMLNode_SetProperty(wn, "text", I18N(s));
+
+              GWEN_XMLNode_SetProperty(wn, "groupId", "999999");
+              GWEN_XMLNode_SetProperty(wn, "flags", "fillX justifyLeft");
+
+              GWEN_XMLNode_AddChild(nBackendRadioWidget, wn);
+              GWEN_Dialog_List_Add(cdlg, subDialogs);
+
+              AB_Banking_EndUseProvider(ab, pro);
+            }
+            else {
+              DBG_ERROR(AQBANKING_LOGDOMAIN, "Could not activate backend [%s]", name);
+            }
+          }
+
+          pd=GWEN_PluginDescription_List2Iterator_Next(pit);
+        }
+        GWEN_PluginDescription_List2Iterator_free(pit);
       }
     }
     else {
@@ -200,16 +204,16 @@ GWEN_DIALOG *AB_SetupNewUserDialog_new(AB_BANKING *ab) {
   if (GWEN_Dialog_List_GetCount(subDialogs)) {
     GWEN_DIALOG *cdlg;
 
-    while ( (cdlg=GWEN_Dialog_List_First(subDialogs)) ) {
+    while ((cdlg=GWEN_Dialog_List_First(subDialogs))) {
       GWEN_Dialog_List_Del(cdlg);
       DBG_NOTICE(AQBANKING_LOGDOMAIN, "Adding dialog %s", GWEN_Dialog_GetId(cdlg));
       rv=GWEN_Dialog_AddSubDialog(dlg, "wiz_stack", cdlg);
       if (rv<0) {
-	DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+        DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
         GWEN_Dialog_List_free(subDialogs);
-	GWEN_Dialog_free(cdlg);
-	GWEN_Dialog_free(dlg);
-	return NULL;
+        GWEN_Dialog_free(cdlg);
+        GWEN_Dialog_free(dlg);
+        return NULL;
       }
       GWEN_Dialog_List2_PushBack(xdlg->backendDialogs, cdlg);
     }
@@ -224,10 +228,11 @@ GWEN_DIALOG *AB_SetupNewUserDialog_new(AB_BANKING *ab) {
 
 
 
-void GWENHYWFAR_CB AB_SetupNewUserDialog_FreeData(void *bp, void *p) {
+void GWENHYWFAR_CB AB_SetupNewUserDialog_FreeData(void *bp, void *p)
+{
   AB_SETUP_NEWUSER_DIALOG *xdlg;
 
-  xdlg=(AB_SETUP_NEWUSER_DIALOG*) p;
+  xdlg=(AB_SETUP_NEWUSER_DIALOG *) p;
   GWEN_Dialog_List2_free(xdlg->backendDialogs); /* don't use _freeAll here! */
   GWEN_StringList_free(xdlg->backendRadioNames);
   GWEN_StringList_free(xdlg->backendNames);
@@ -237,7 +242,8 @@ void GWENHYWFAR_CB AB_SetupNewUserDialog_FreeData(void *bp, void *p) {
 
 
 
-void AB_SetupNewUserDialog_Init(GWEN_DIALOG *dlg) {
+void AB_SetupNewUserDialog_Init(GWEN_DIALOG *dlg)
+{
   AB_SETUP_NEWUSER_DIALOG *xdlg;
   GWEN_DB_NODE *dbPrefs;
   int i;
@@ -249,43 +255,43 @@ void AB_SetupNewUserDialog_Init(GWEN_DIALOG *dlg) {
   dbPrefs=GWEN_Dialog_GetPreferences(dlg);
 
   GWEN_Dialog_SetCharProperty(dlg,
-			      "",
-			      GWEN_DialogProperty_Title,
-			      0,
-			      I18N("New User Wizard"),
-			      0);
+                              "",
+                              GWEN_DialogProperty_Title,
+                              0,
+                              I18N("New User Wizard"),
+                              0);
 
   /* select first page */
   GWEN_Dialog_SetIntProperty(dlg, "wiz_stack", GWEN_DialogProperty_Value, 0, 0, 0);
 
   /* setup intro page */
   GWEN_Dialog_SetCharProperty(dlg,
-			      "wiz_begin_label",
-			      GWEN_DialogProperty_Title,
-			      0,
+                              "wiz_begin_label",
+                              GWEN_DialogProperty_Title,
+                              0,
                               I18N("<html>"
                                    "<p>This dialog assists you in creating an online banking user."
-				   "The following steps are:</p>"
+                                   "The following steps are:</p>"
                                    "<ul>"
-				   "<li>select the banking protocol</li>"
-				   "<li>select the type of user to create</li>"
+                                   "<li>select the banking protocol</li>"
+                                   "<li>select the type of user to create</li>"
                                    "</ul>"
                                    "</html>"
                                    "This dialog assists you in creating an online banking user.\n"
                                    "The following steps are:\n"
                                    " - select the banking protocol\n"
-				   " - select the type of user to create\n"),
-			      0);
+                                   " - select the type of user to create\n"),
+                              0);
 
   /* read width */
   i=GWEN_DB_GetIntValue(dbPrefs, "dialog_width", 0, -1);
   if (i>=DIALOG_MINWIDTH)
-      GWEN_Dialog_SetIntProperty(dlg, "", GWEN_DialogProperty_Width, 0, i, 0);
+    GWEN_Dialog_SetIntProperty(dlg, "", GWEN_DialogProperty_Width, 0, i, 0);
 
   /* read height */
   i=GWEN_DB_GetIntValue(dbPrefs, "dialog_height", 0, -1);
   if (i>=DIALOG_MINHEIGHT)
-      GWEN_Dialog_SetIntProperty(dlg, "", GWEN_DialogProperty_Height, 0, i, 0);
+    GWEN_Dialog_SetIntProperty(dlg, "", GWEN_DialogProperty_Height, 0, i, 0);
 
   /* disable next and previous buttons */
   GWEN_Dialog_SetIntProperty(dlg, "wiz_prev_button", GWEN_DialogProperty_Enabled, 0, 0, 0);
@@ -294,7 +300,8 @@ void AB_SetupNewUserDialog_Init(GWEN_DIALOG *dlg) {
 
 
 
-void AB_SetupNewUserDialog_Fini(GWEN_DIALOG *dlg) {
+void AB_SetupNewUserDialog_Fini(GWEN_DIALOG *dlg)
+{
   AB_SETUP_NEWUSER_DIALOG *xdlg;
   int i;
   GWEN_DB_NODE *dbPrefs;
@@ -321,14 +328,14 @@ void AB_SetupNewUserDialog_Fini(GWEN_DIALOG *dlg) {
       GWEN_DIALOG *cdlg;
 
       cdlg=GWEN_Dialog_List2Iterator_Data(it);
-      while(cdlg && j>0) {
+      while (cdlg && j>0) {
         j--;
-	cdlg=GWEN_Dialog_List2Iterator_Next(it);
+        cdlg=GWEN_Dialog_List2Iterator_Next(it);
       }
       GWEN_Dialog_List2Iterator_free(it);
 
       if (cdlg)
-	xdlg->selectedType=AB_UserTypePageDialog_GetSelectedType(cdlg);
+        xdlg->selectedType=AB_UserTypePageDialog_GetSelectedType(cdlg);
     }
   }
 
@@ -338,28 +345,29 @@ void AB_SetupNewUserDialog_Fini(GWEN_DIALOG *dlg) {
   /* store dialog width */
   i=GWEN_Dialog_GetIntProperty(dlg, "", GWEN_DialogProperty_Width, 0, -1);
   GWEN_DB_SetIntValue(dbPrefs,
-		      GWEN_DB_FLAGS_OVERWRITE_VARS,
-		      "dialog_width",
-		      i);
+                      GWEN_DB_FLAGS_OVERWRITE_VARS,
+                      "dialog_width",
+                      i);
 
   /* store dialog height */
   i=GWEN_Dialog_GetIntProperty(dlg, "", GWEN_DialogProperty_Height, 0, -1);
   GWEN_DB_SetIntValue(dbPrefs,
-		      GWEN_DB_FLAGS_OVERWRITE_VARS,
-		      "dialog_height",
-		      i);
+                      GWEN_DB_FLAGS_OVERWRITE_VARS,
+                      "dialog_height",
+                      i);
 }
 
 
 
-int AB_SetupNewUserDialog_EnterPage(GWEN_DIALOG *dlg, int page, int forwards) {
+int AB_SetupNewUserDialog_EnterPage(GWEN_DIALOG *dlg, int page, int forwards)
+{
   AB_SETUP_NEWUSER_DIALOG *xdlg;
 
   assert(dlg);
   xdlg=GWEN_INHERIT_GETDATA(GWEN_DIALOG, AB_SETUP_NEWUSER_DIALOG, dlg);
   assert(xdlg);
 
-  switch(page) {
+  switch (page) {
   case PAGE_BEGIN:
     GWEN_Dialog_SetIntProperty(dlg, "wiz_prev_button", GWEN_DialogProperty_Enabled, 0, 0, 0);
     GWEN_Dialog_SetIntProperty(dlg, "wiz_stack", GWEN_DialogProperty_Value, 0, page, 0);
@@ -373,7 +381,7 @@ int AB_SetupNewUserDialog_EnterPage(GWEN_DIALOG *dlg, int page, int forwards) {
     return GWEN_DialogEvent_ResultHandled;
 
   default:
-    if (forwards){
+    if (forwards) {
       DBG_NOTICE(0, "About to enter page %d", page);
       GWEN_Dialog_SetCharProperty(dlg, "wiz_next_button", GWEN_DialogProperty_Title, 0, I18N("Run"), 0);
       GWEN_Dialog_SetIntProperty(dlg, "wiz_stack", GWEN_DialogProperty_Value, 0, page, 0);
@@ -387,7 +395,8 @@ int AB_SetupNewUserDialog_EnterPage(GWEN_DIALOG *dlg, int page, int forwards) {
 
 
 
-int AB_SetupNewUserDialog_DetermineBackendIndex(GWEN_DIALOG *dlg) {
+int AB_SetupNewUserDialog_DetermineBackendIndex(GWEN_DIALOG *dlg)
+{
   AB_SETUP_NEWUSER_DIALOG *xdlg;
   GWEN_STRINGLISTENTRY *se;
   int i=0;
@@ -397,7 +406,7 @@ int AB_SetupNewUserDialog_DetermineBackendIndex(GWEN_DIALOG *dlg) {
   assert(xdlg);
 
   se=GWEN_StringList_FirstEntry(xdlg->backendRadioNames);
-  while(se) {
+  while (se) {
     const char *s;
 
     s=GWEN_StringListEntry_Data(se);
@@ -415,7 +424,8 @@ int AB_SetupNewUserDialog_DetermineBackendIndex(GWEN_DIALOG *dlg) {
 
 
 
-int AB_SetupNewUserDialog_Next(GWEN_DIALOG *dlg) {
+int AB_SetupNewUserDialog_Next(GWEN_DIALOG *dlg)
+{
   AB_SETUP_NEWUSER_DIALOG *xdlg;
   int page;
 
@@ -449,7 +459,8 @@ int AB_SetupNewUserDialog_Next(GWEN_DIALOG *dlg) {
 
 
 
-int AB_SetupNewUserDialog_Previous(GWEN_DIALOG *dlg) {
+int AB_SetupNewUserDialog_Previous(GWEN_DIALOG *dlg)
+{
   AB_SETUP_NEWUSER_DIALOG *xdlg;
   int page;
 
@@ -472,7 +483,8 @@ int AB_SetupNewUserDialog_Previous(GWEN_DIALOG *dlg) {
 
 
 
-int AB_SetupNewUserDialog_HandleActivated(GWEN_DIALOG *dlg, const char *sender) {
+int AB_SetupNewUserDialog_HandleActivated(GWEN_DIALOG *dlg, const char *sender)
+{
   DBG_NOTICE(0, "Activated: %s", sender);
   if (strcasecmp(sender, "wiz_prev_button")==0)
     return AB_SetupNewUserDialog_Previous(dlg);
@@ -490,15 +502,16 @@ int AB_SetupNewUserDialog_HandleActivated(GWEN_DIALOG *dlg, const char *sender)
 
 
 int GWENHYWFAR_CB AB_SetupNewUserDialog_SignalHandler(GWEN_DIALOG *dlg,
-						      GWEN_DIALOG_EVENTTYPE t,
-						      const char *sender) {
+                                                      GWEN_DIALOG_EVENTTYPE t,
+                                                      const char *sender)
+{
   AB_SETUP_NEWUSER_DIALOG *xdlg;
 
   assert(dlg);
   xdlg=GWEN_INHERIT_GETDATA(GWEN_DIALOG, AB_SETUP_NEWUSER_DIALOG, dlg);
   assert(xdlg);
 
-  switch(t) {
+  switch (t) {
   case GWEN_DialogEvent_TypeInit:
     AB_SetupNewUserDialog_Init(dlg);
     return GWEN_DialogEvent_ResultHandled;;
@@ -525,7 +538,8 @@ int GWENHYWFAR_CB AB_SetupNewUserDialog_SignalHandler(GWEN_DIALOG *dlg,
 
 
 
-const char *AB_SetupNewUserDialog_GetSelectedBackend(const GWEN_DIALOG *dlg) {
+const char *AB_SetupNewUserDialog_GetSelectedBackend(const GWEN_DIALOG *dlg)
+{
   AB_SETUP_NEWUSER_DIALOG *xdlg;
 
   assert(dlg);
@@ -537,7 +551,8 @@ const char *AB_SetupNewUserDialog_GetSelectedBackend(const GWEN_DIALOG *dlg) {
 
 
 
-int AB_SetupNewUserDialog_GetSelectedType(const GWEN_DIALOG *dlg) {
+int AB_SetupNewUserDialog_GetSelectedType(const GWEN_DIALOG *dlg)
+{
   AB_SETUP_NEWUSER_DIALOG *xdlg;
 
   assert(dlg);
