@@ -15,13 +15,11 @@
 
 
 #include "dlg_usertype_pagedefault_p.h"
-#include "i18n_l.h"
 
-#include <aqhbci/provider.h>
-
-#include <aqbanking/user.h>
+#include "aqbanking/i18n_l.h"
+#include "aqbanking/backendsupport/user.h"
+#include "aqbanking/dialogs/dlg_usertype_page_be.h"
 #include <aqbanking/banking_be.h>
-#include <aqbanking/dlg_usertype_page_be.h>
 
 #include <gwenhywfar/gwenhywfar.h>
 #include <gwenhywfar/misc.h>
@@ -33,7 +31,8 @@
 
 
 
-GWEN_DIALOG *AB_UserTypePageDefaultDialog_new(AB_BANKING *ab) {
+GWEN_DIALOG *AB_UserTypePageDefaultDialog_new(AB_BANKING *ab)
+{
   GWEN_DIALOG *dlg;
   GWEN_BUFFER *fbuf;
   int rv;
@@ -43,11 +42,11 @@ GWEN_DIALOG *AB_UserTypePageDefaultDialog_new(AB_BANKING *ab) {
 
   /* get path of dialog description file */
   fbuf=GWEN_Buffer_new(0, 256, 0, 1);
-  rv=GWEN_PathManager_FindFile(GWEN_PM_LIBNAME, GWEN_PM_SYSDATADIR,
-			       "aqbanking/dialogs/dlg_usertype_pagedefault.dlg",
-			       fbuf);
+  rv=GWEN_PathManager_FindFile(AB_PM_LIBNAME, AB_PM_DATADIR,
+                               "aqbanking/dialogs/dlg_usertype_pagedefault.dlg",
+                               fbuf);
   if (rv<0) {
-    DBG_INFO(AQHBCI_LOGDOMAIN, "Dialog description file not found (%d).", rv);
+    DBG_INFO(AQBANKING_LOGDOMAIN, "Dialog description file not found (%d).", rv);
     GWEN_Buffer_free(fbuf);
     GWEN_Dialog_free(dlg);
     return NULL;
@@ -56,7 +55,7 @@ GWEN_DIALOG *AB_UserTypePageDefaultDialog_new(AB_BANKING *ab) {
   /* read dialog from dialog description file */
   rv=GWEN_Dialog_ReadXmlFile(dlg, GWEN_Buffer_GetStart(fbuf));
   if (rv<0) {
-    DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d).", rv);
+    DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d).", rv);
     GWEN_Buffer_free(fbuf);
     GWEN_Dialog_free(dlg);
     return NULL;
@@ -65,9 +64,9 @@ GWEN_DIALOG *AB_UserTypePageDefaultDialog_new(AB_BANKING *ab) {
 
   /* add media paths for icons */
   GWEN_Dialog_AddMediaPathsFromPathManager(dlg,
-					   GWEN_PM_LIBNAME,
-					   GWEN_PM_SYSDATADIR,
-					   "aqbanking/dialogs/dialogs");
+                                           GWEN_PM_LIBNAME,
+                                           GWEN_PM_SYSDATADIR,
+                                           "aqbanking/dialogs/dialogs");
 
   /* done */
   return dlg;
@@ -75,7 +74,8 @@ GWEN_DIALOG *AB_UserTypePageDefaultDialog_new(AB_BANKING *ab) {
 
 
 
-void AB_UserTypePageDefaultDialog_Init(GWEN_DIALOG *dlg) {
+void AB_UserTypePageDefaultDialog_Init(GWEN_DIALOG *dlg)
+{
   GWEN_Dialog_SetCharProperty(dlg, "defaultIntroLabel", GWEN_DialogProperty_Title, 0,
                               I18N("<html>"
                                    "<p>Click on the <i>run</i> button below to create the user.</p>"
@@ -86,14 +86,16 @@ void AB_UserTypePageDefaultDialog_Init(GWEN_DIALOG *dlg) {
 
 
 
-void AB_UserTypePageDefaultDialog_Fini(GWEN_DIALOG *dlg) {
+void AB_UserTypePageDefaultDialog_Fini(GWEN_DIALOG *dlg)
+{
   DBG_NOTICE(AQBANKING_LOGDOMAIN, "fini called");
   AB_UserTypePageDialog_SetSelectedType(dlg, 0);
 }
 
 
 
-int AB_UserTypePageDefaultDialog_HandleActivated(GWEN_DIALOG *dlg, const char *sender) {
+int AB_UserTypePageDefaultDialog_HandleActivated(GWEN_DIALOG *dlg, const char *sender)
+{
   /* nothing for now */
   return GWEN_DialogEvent_ResultNotHandled;
 }
@@ -101,9 +103,10 @@ int AB_UserTypePageDefaultDialog_HandleActivated(GWEN_DIALOG *dlg, const char *s
 
 
 int GWENHYWFAR_CB AB_UserTypePageDefaultDialog_SignalHandler(GWEN_DIALOG *dlg,
-							     GWEN_DIALOG_EVENTTYPE t,
-							     const char *sender) {
-  switch(t) {
+                                                             GWEN_DIALOG_EVENTTYPE t,
+                                                             const char *sender)
+{
+  switch (t) {
   case GWEN_DialogEvent_TypeInit:
     AB_UserTypePageDefaultDialog_Init(dlg);
     return GWEN_DialogEvent_ResultHandled;;
