@@ -17,6 +17,7 @@
 #include "aqhbci_l.h"
 #include "accountjob_l.h"
 #include "job_l.h"
+#include "aqhbci/joblayer/job_crypt.h"
 #include "user_l.h"
 
 #include <gwenhywfar/debug.h>
@@ -372,10 +373,11 @@ int AH_Job_GetTransactionsCreditCard_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *c
 
   dbResponses=AH_Job_GetResponses(j);
   assert(dbResponses);
+#if 0
   DBG_INFO(AQHBCI_LOGDOMAIN, "Response:");
   GWEN_DB_Dump(dbResponses, 2);
   DBG_INFO(AQHBCI_LOGDOMAIN, "Response end");
-
+#endif
 
   a=AH_AccountJob_GetAccount(j);
   assert(a);
@@ -493,6 +495,7 @@ int AH_Job_GetTransactionsCreditCard_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *c
         t=AB_Transaction_new();
         if (ref)
           AB_Transaction_SetFiId(t, ref);
+        AB_Transaction_SetType(t, AB_Transaction_TypeStatement);
         AB_Transaction_SetUniqueAccountId(t, AB_Account_GetUniqueId(a));
         AB_Transaction_SetLocalBankCode(t, AB_User_GetBankCode(u));
         AB_Transaction_SetLocalAccountNumber(t, AB_Account_GetAccountNumber(a));
