@@ -12,6 +12,7 @@
 
 #include "provider.h"
 #include "aqhbci/tan/tanmethod.h"
+#include "aqhbci/joblayer/job_l.h"
 #include "hbci_l.h"
 
 
@@ -29,18 +30,5 @@ int AH_Provider_SendDtazv(AB_PROVIDER *pro,
 int AH_Provider_WriteValueToDb(const AB_VALUE *v, GWEN_DB_NODE *dbV);
 
 
-int AH_Provider_InputTanWithChallenge(AB_PROVIDER *pro,
-                                      AB_USER *u,
-                                      const AH_TAN_METHOD *tanMethodDescription,
-                                      const char *sChallenge,
-                                      const char *sChallengeHhd,
-                                      char *passwordBuffer,
-                                      int passwordMinLen,
-                                      int passwordMaxLen);
-
-
-
-
-
 #endif
 
