@@ -44,7 +44,6 @@ GWEN_INHERIT_FUNCTIONS(AH_JOB);
 
 
 
-
 void AH_Job_free(AH_JOB *j)
 {
   if (j) {
@@ -95,6 +94,8 @@ int AH_Job_SampleBpdVersions(const char *name,
   assert(name);
   assert(u);
 
+  DBG_INFO(AQHBCI_LOGDOMAIN, "Sampling BPD versions for job \"%s\"", name?name:"<noname>");
+
   /* get job descriptions */
   e=AH_User_GetMsgEngine(u);
   assert(e);
@@ -429,6 +430,20 @@ const char *AH_Job_GetResponseName(const AH_JOB *j)
 
 
 
+void AH_Job_SetResponseName(AH_JOB *j, const char *s)
+{
+  assert(j);
+  assert(j->usage);
+  if (j->responseName)
+    free(j->responseName);
+  if (s)
+    j->responseName=strdup(s);
+  else
+    j->responseName=NULL;
+}
+
+
+
 int AH_Job_GetMinSignatures(const AH_JOB *j)
 {
   assert(j);
@@ -1120,6 +1135,25 @@ void AH_Job_Dump(const AH_JOB *j, FILE *f, unsigned int insert)
     fprintf(f, "OUTBOX ");
   fprintf(f, ")\n");
 
+  if (j->segResults) {
+    AH_RESULT *r;
+
+    for (k=0; k<insert; k++)
+      fprintf(f, " ");
+    fprintf(f, "Segment results:\n");
+    r=AH_Result_List_First(j->segResults);
+    while (r) {
+      int code;
+      const char *text;
+
+      code=AH_Result_GetCode(r);
+      text=AH_Result_GetText(r);
+      for (k=0; k<insert+2; k++)
+        fprintf(f, " ");
+      fprintf(f, "%04d: %s\n", code, text?text:"<no text>");
+      r=AH_Result_List_Next(r);
+    }
+  }
 
   if (j->jobResponses) {
     for (k=0; k<insert; k++)
@@ -1293,238 +1327,6 @@ void AH_Job_SetExpectedCrypter(AH_JOB *j, const char *s)
 
 
 
-int AH_Job_CheckEncryption(AH_JOB *j, GWEN_DB_NODE *dbRsp)
-{
-  if (AH_User_GetCryptMode(j->user)==AH_CryptMode_Pintan) {
-    DBG_DEBUG(AQHBCI_LOGDOMAIN, "Not checking security in PIN/TAN mode");
-  }
-  else {
-    GWEN_DB_NODE *dbSecurity;
-    const char *s;
-
-    assert(j);
-    assert(j->usage);
-    assert(dbRsp);
-    dbSecurity=GWEN_DB_GetGroup(dbRsp, GWEN_PATH_FLAGS_NAMEMUSTEXIST, "security");
-    if (!dbSecurity) {
-      DBG_ERROR(AQHBCI_LOGDOMAIN, "No security settings, should not happen");
-      GWEN_Gui_ProgressLog(0,
-                           GWEN_LoggerLevel_Error,
-                           I18N("Response without security info (internal)"));
-      return AB_ERROR_SECURITY;
-    }
-
-    s=GWEN_DB_GetCharValue(dbSecurity, "crypter", 0, 0);
-    if (s) {
-      DBG_DEBUG(AQHBCI_LOGDOMAIN, "Response encrypted with key [%s]", s);
-
-      if (*s=='!' || *s=='?') {
-        DBG_ERROR(AQHBCI_LOGDOMAIN, "Encrypted with invalid key (%s)", s);
-        GWEN_Gui_ProgressLog(0,
-                             GWEN_LoggerLevel_Error,
-                             I18N("Response encrypted with invalid key"));
-        return AB_ERROR_SECURITY;
-      }
-    }
-
-    if (j->expectedCrypter) {
-      /* check crypter */
-      if (!s) {
-        DBG_ERROR(AQHBCI_LOGDOMAIN,
-                  "Response is not encrypted (but expected to be)");
-        GWEN_Gui_ProgressLog(0,
-                             GWEN_LoggerLevel_Error,
-                             I18N("Response is not encrypted as expected"));
-        return AB_ERROR_SECURITY;
-
-      }
-
-      if (strcasecmp(s, j->expectedCrypter)!=0) {
-        DBG_WARN(AQHBCI_LOGDOMAIN,
-                 "Not encrypted with the expected key "
-                 "(exp: \"%s\", is: \"%s\"",
-                 j->expectedCrypter, s);
-        /*
-         GWEN_Gui_ProgressLog(
-                              0,
-                              GWEN_LoggerLevel_Error,
-                              I18N("Response not encrypted with expected key"));
-         return AB_ERROR_SECURITY;
-         */
-      }
-    }
-    else {
-      DBG_DEBUG(AQHBCI_LOGDOMAIN, "No specific encrypter expected");
-    }
-  }
-
-  return 0;
-}
-
-
-
-int AH_Job_CheckSignature(AH_JOB *j, GWEN_DB_NODE *dbRsp)
-{
-  if (AH_User_GetCryptMode(j->user)==AH_CryptMode_Pintan) {
-    DBG_DEBUG(AQHBCI_LOGDOMAIN, "Not checking signature in PIN/TAN mode");
-  }
-  else {
-    GWEN_DB_NODE *dbSecurity;
-    int i;
-    uint32_t uFlags;
-
-    assert(j);
-    assert(j->usage);
-
-    uFlags=AH_User_GetFlags(j->user);
-
-    assert(dbRsp);
-    dbSecurity=GWEN_DB_GetGroup(dbRsp, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
-                                "security");
-    if (!dbSecurity) {
-      DBG_ERROR(AQHBCI_LOGDOMAIN,
-                "No security settings, should not happen");
-      GWEN_Gui_ProgressLog(
-        0,
-        GWEN_LoggerLevel_Error,
-        I18N("Response without security info (internal)"));
-      return GWEN_ERROR_GENERIC;
-    }
-
-    /* check for invalid signers */
-    for (i=0; ; i++) {
-      const char *s;
-
-      s=GWEN_DB_GetCharValue(dbSecurity, "signer", i, 0);
-      if (!s)
-        break;
-      if (*s=='!') {
-        DBG_ERROR(AQHBCI_LOGDOMAIN,
-                  "Invalid signature found, will not tolerate it");
-        GWEN_Gui_ProgressLog(0,
-                             GWEN_LoggerLevel_Error,
-                             I18N("Invalid bank signature"));
-        return AB_ERROR_SECURITY;
-      }
-    } /* for */
-
-    if (j->expectedSigner && !(uFlags & AH_USER_FLAGS_BANK_DOESNT_SIGN)) {
-      /* check signer */
-      for (i=0; ; i++) {
-        const char *s;
-
-        s=GWEN_DB_GetCharValue(dbSecurity, "signer", i, 0);
-        if (!s) {
-          DBG_ERROR(AQHBCI_LOGDOMAIN,
-                    "Not signed by expected signer (%d)", i);
-          GWEN_Gui_ProgressLog(0,
-                               GWEN_LoggerLevel_Error,
-                               I18N("Response not signed by the bank"));
-          if (i==0) {
-            int but;
-
-            /* check whether the user want's to accept the unsigned message */
-            but=GWEN_Gui_MessageBox(GWEN_GUI_MSG_FLAGS_TYPE_WARN |
-                                    GWEN_GUI_MSG_FLAGS_CONFIRM_B1 |
-                                    GWEN_GUI_MSG_FLAGS_SEVERITY_DANGEROUS,
-                                    I18N("Security Warning"),
-                                    I18N(
-                                      "The HBCI response of the bank has not been signed by the bank, \n"
-                                      "contrary to what has been expected. This can be the case because the \n"
-                                      "bank just stopped signing their HBCI responses. This error message \n"
-                                      "would also occur if there were a replay attack against your computer \n"
-                                      "in progress right now, which is probably quite unlikely. \n"
-                                      " \n"
-                                      "Please contact your bank and ask them whether their HBCI server \n"
-                                      "stopped signing the HBCI responses. If the bank is concerned about \n"
-                                      "your security, it should not stop signing the HBCI responses. \n"
-                                      " \n"
-                                      "Do you nevertheless want to accept this response this time or always?"
-                                      "<html><p>"
-                                      "The HBCI response of the bank has not been signed by the bank, \n"
-                                      "contrary to what has been expected. This can be the case because the \n"
-                                      "bank just stopped signing their HBCI responses. This error message \n"
-                                      "would also occur if there were a replay attack against your computer \n"
-                                      "in progress right now, which is probably quite unlikely. \n"
-                                      "</p><p>"
-                                      "Please contact your bank and ask them whether their HBCI server \n"
-                                      "stopped signing the HBCI responses. If the bank is concerned about \n"
-                                      "your security, it should not stop signing the HBCI responses. \n"
-                                      "</p><p>"
-                                      "Do you nevertheless want to accept this response this time or always?"
-                                      "</p></html>"
-                                    ),
-                                    I18N("Accept this time"),
-                                    I18N("Accept always"),
-                                    I18N("Abort"), 0);
-            if (but==1) {
-              GWEN_Gui_ProgressLog(0,
-                                   GWEN_LoggerLevel_Notice,
-                                   I18N("User accepts this unsigned "
-                                        "response"));
-              AH_Job_SetExpectedSigner(j, 0);
-              break;
-            }
-            else if (but==2) {
-              GWEN_Gui_ProgressLog(0,
-                                   GWEN_LoggerLevel_Notice,
-                                   I18N("User accepts all further unsigned "
-                                        "responses"));
-              AH_User_AddFlags(j->user, AH_USER_FLAGS_BANK_DOESNT_SIGN);
-              AH_Job_SetExpectedSigner(j, 0);
-              break;
-            }
-            else {
-              GWEN_Gui_ProgressLog(0,
-                                   GWEN_LoggerLevel_Error,
-                                   I18N("Aborted"));
-              return AB_ERROR_SECURITY;
-            }
-          }
-          else {
-            int ii;
-
-            DBG_ERROR(AQHBCI_LOGDOMAIN,
-                      "Job signed with unexpected key(s)"
-                      "(was expecting \"%s\"):",
-                      j->expectedSigner);
-            for (ii=0; ; ii++) {
-              s=GWEN_DB_GetCharValue(dbSecurity, "signer", ii, 0);
-              if (!s)
-                break;
-              DBG_ERROR(AQHBCI_LOGDOMAIN,
-                        "Signed unexpectedly with key \"%s\"", s);
-            }
-            return AB_ERROR_SECURITY;
-          }
-        }
-        else {
-          if (strcasecmp(s, j->expectedSigner)==0) {
-            DBG_DEBUG(AQHBCI_LOGDOMAIN,
-                      "Jobs signed as expected with \"%s\"",
-                      j->expectedSigner);
-            break;
-          }
-          else if (*s!='!' && *s!='?') {
-            DBG_INFO(AQHBCI_LOGDOMAIN,
-                     "Signer name does not match expected name (%s!=%s), "
-                     "but we accept it anyway",
-                     s, j->expectedSigner);
-            break;
-          }
-        }
-      } /* for */
-      DBG_DEBUG(AQHBCI_LOGDOMAIN, "Signature check ok");
-    }
-    else {
-      DBG_DEBUG(AQHBCI_LOGDOMAIN, "No signature expected");
-    }
-  }
-  return 0;
-}
-
-
-
 const char *AH_Job_GetUsedTan(const AH_JOB *j)
 {
   assert(j);
@@ -1682,174 +1484,6 @@ void AH_Job_AddTransfer(AH_JOB *j, AB_TRANSACTION *t)
 
 
 
-static int AH_Job__SepaProfileSupported(GWEN_DB_NODE *profile,
-                                        const GWEN_STRINGLIST *descriptors)
-{
-  GWEN_STRINGLISTENTRY *se;
-  char pattern[13];
-  const char *s;
-
-  /* patterns shall always have the form *xxx.yyy.zz* */
-  pattern[0]=pattern[11]='*';
-  pattern[12]='\0';
-
-  /* Well formed type strings are exactly 10 characters long. Others
-   * will either not match or be rejected by the exporter. */
-  strncpy(pattern+1, GWEN_DB_GetCharValue(profile, "type", 0, ""), 10);
-  se=GWEN_StringList_FirstEntry(descriptors);
-  while (se) {
-    s=GWEN_StringListEntry_Data(se);
-    if (s && GWEN_Text_ComparePattern(s, pattern, 1)!=-1) {
-      /* record the descriptor matching this profile */
-      GWEN_DB_SetCharValue(profile, GWEN_DB_FLAGS_OVERWRITE_VARS,
-                           "descriptor", s);
-      break;
-    }
-    se=GWEN_StringListEntry_Next(se);
-  }
-  if (se)
-    return 1;
-  else
-    return 0;
-}
-
-
-
-static int AH_Job__SortSepaProfiles(const void *a, const void *b)
-{
-  GWEN_DB_NODE **ppa=(GWEN_DB_NODE **)a;
-  GWEN_DB_NODE **ppb=(GWEN_DB_NODE **)b;
-  GWEN_DB_NODE *pa=*ppa;
-  GWEN_DB_NODE *pb=*ppb;
-  int res;
-
-  /* This function is supposed to return a list of profiles in order
-   * of decreasing precedence. */
-  res=strcmp(GWEN_DB_GetCharValue(pb, "type", 0, ""),
-             GWEN_DB_GetCharValue(pa, "type", 0, ""));
-  if (res)
-    return res;
-
-  res=strcmp(GWEN_DB_GetCharValue(pb, "name", 0, ""),
-             GWEN_DB_GetCharValue(pa, "name", 0, ""));
-
-  return res;
-}
-
-
-
-GWEN_DB_NODE *AH_Job_FindSepaProfile(AH_JOB *j, const char *type,
-                                     const char *name)
-{
-  const GWEN_STRINGLIST *descriptors;
-  GWEN_DB_NODE *dbProfiles;
-
-  assert(j);
-
-  if (j->sepaDescriptors)
-    descriptors=j->sepaDescriptors;
-  else
-    descriptors=AH_User_GetSepaDescriptors(j->user);
-  if (GWEN_StringList_Count(descriptors)==0) {
-    DBG_ERROR(AQHBCI_LOGDOMAIN,
-              "No SEPA descriptor found, please update your account information");
-    return NULL;
-  }
-
-  if (name) {
-    GWEN_DB_NODE *profile;
-
-    profile=AB_Banking_GetImExporterProfile(AH_Job_GetBankingApi(j),
-                                            "sepa", name);
-    if (!profile) {
-      DBG_ERROR(AQHBCI_LOGDOMAIN,
-                "Profile \"%s\" not available", name);
-      return NULL;
-    }
-    if (GWEN_Text_ComparePattern(GWEN_DB_GetCharValue(profile, "type", 0, ""),
-                                 type, 1)==-1) {
-      DBG_ERROR(AQHBCI_LOGDOMAIN,
-                "Profile \"%s\" does not match type speecification (\"%s\")",
-                name, type);
-      return NULL;
-    }
-    if (!AH_Job__SepaProfileSupported(profile, descriptors)) {
-      DBG_ERROR(AQHBCI_LOGDOMAIN,
-                "Profile \"%s\" not supported by bank server", name);
-      return NULL;
-    }
-    j->sepaProfile=profile;
-    return profile;
-  }
-
-  if (!type)
-    return j->sepaProfile;
-
-  if (j->sepaProfile) {
-    if (GWEN_Text_ComparePattern(GWEN_DB_GetCharValue(j->sepaProfile, "type",
-                                                      0, ""),
-                                 type, 1)!=-1)
-      return j->sepaProfile;
-    else {
-      GWEN_DB_Group_free(j->sepaProfile);
-      j->sepaProfile=NULL;
-    }
-  }
-
-  dbProfiles=AB_Banking_GetImExporterProfiles(AH_Job_GetBankingApi(j), "sepa");
-  if (dbProfiles) {
-    GWEN_DB_NODE *n, *nn;
-    unsigned int pCount=0;
-
-    n=GWEN_DB_GetFirstGroup(dbProfiles);
-    while (n) {
-      nn=n;
-      n=GWEN_DB_GetNextGroup(n);
-
-      if (GWEN_Text_ComparePattern(GWEN_DB_GetCharValue(nn, "type", 0, ""),
-                                   type, 1)!=-1 &&
-          AH_Job__SepaProfileSupported(nn, descriptors))
-        pCount++;
-      else {
-        GWEN_DB_UnlinkGroup(nn);
-        GWEN_DB_Group_free(nn);
-      }
-    }
-
-    if (pCount) {
-      GWEN_DB_NODE **orderedProfiles;
-      unsigned int i;
-
-      orderedProfiles=malloc(pCount*sizeof(GWEN_DB_NODE *));
-      assert(orderedProfiles);
-      n=GWEN_DB_GetFirstGroup(dbProfiles);
-      for (i=0; i<pCount && n; i++) {
-        orderedProfiles[i]=n;
-        n=GWEN_DB_GetNextGroup(n);
-      }
-      assert(i==pCount && !n);
-      qsort(orderedProfiles, pCount, sizeof(GWEN_DB_NODE *),
-            AH_Job__SortSepaProfiles);
-      GWEN_DB_UnlinkGroup(orderedProfiles[0]);
-      j->sepaProfile=orderedProfiles[0];
-      free(orderedProfiles);
-    }
-    else {
-      DBG_ERROR(AQHBCI_LOGDOMAIN,
-                "No supported SEPA format found for job \"%s\"", j->name);
-    }
-    GWEN_DB_Group_free(dbProfiles);
-  }
-  else {
-    DBG_ERROR(AQHBCI_LOGDOMAIN,
-              "No SEPA profiles found");
-  }
-
-  return j->sepaProfile;
-}
-
-
-
 AB_TRANSACTION_COMMAND AH_Job_GetSupportedCommand(const AH_JOB *j)
 {
   assert(j);
@@ -1944,8 +1578,6 @@ void AH_Job_SetStatusOnCommands(AH_JOB *j, AB_TRANSACTION_STATUS status)
 
 
 #include "job_new.c"
-#include "job_commit.c"
-#include "job_commit_account.c"
 #include "job_virtual.c"
 
 
