@@ -39,7 +39,9 @@ GWEN_INHERIT(AB_IMEXPORTER, AB_IMEXPORTER_XML);
  * ------------------------------------------------------------------------------------------------
  */
 
-static AB_TRANSACTION *dbToTransaction(AB_IMEXPORTER *ie, GWEN_DB_NODE *dbAccount, GWEN_DB_NODE *dbTransaction);
+static void _readAccountsFromDb(AB_IMEXPORTER_CONTEXT *ctx, GWEN_DB_NODE *dbData);
+static int _readSecuritiesFromDb(AB_IMEXPORTER_CONTEXT *ctx, GWEN_DB_NODE *dbData);
+static AB_TRANSACTION *dbToTransaction(GWEN_DB_NODE *dbAccount, GWEN_DB_NODE *dbTransaction);
 static void handleTransactionDetails(AB_TRANSACTION *t, const char *sDetails);
 
 
@@ -163,6 +165,8 @@ int AB_ImExporterXML_Import(AB_IMEXPORTER *ie,
     GWEN_XMLNODE *xmlDocData;
     GWEN_DB_NODE *dbData;
     int rv;
+    uint32_t xmlFlags=GWEN_XML_FLAGS_HANDLE_COMMENTS | GWEN_XML_FLAGS_HANDLE_HEADERS;
+    const char *s;
 
     dbSubParams=GWEN_DB_GetGroup(dbParams, GWEN_PATH_FLAGS_NAMEMUSTEXIST, "params");
     if (!dbSubParams) {
@@ -170,7 +174,11 @@ int AB_ImExporterXML_Import(AB_IMEXPORTER *ie,
       return GWEN_ERROR_INVALID;
     }
 
-    xmlDocData=AB_ImExporterXML_ReadXmlFromSio(ie, sio);
+    s=GWEN_DB_GetCharValue(dbSubParams, "xmlFlags", 0, NULL);
+    if (s && strcasecmp(s, "sgml")==0)
+      xmlFlags|=GWEN_XML_FLAGS_SGML|GWEN_XML_FLAGS_TOLERANT_ENDTAGS;
+
+    xmlDocData=AB_ImExporterXML_ReadXmlFromSio(ie, sio, xmlFlags);
     if (xmlDocData==NULL) {
       DBG_ERROR(AQBANKING_LOGDOMAIN, "Could not read XML input");
       return GWEN_ERROR_INVALID;
@@ -572,7 +580,7 @@ const char *AB_ImExporterXML_GetCharValueByPath(GWEN_XMLNODE *xmlNode, const cha
 
 
 
-GWEN_XMLNODE *AB_ImExporterXML_ReadXmlFromSio(AB_IMEXPORTER *ie, GWEN_SYNCIO *sio)
+GWEN_XMLNODE *AB_ImExporterXML_ReadXmlFromSio(AB_IMEXPORTER *ie, GWEN_SYNCIO *sio, uint32_t xmlFlags)
 {
   int rv;
   GWEN_XMLNODE *xmlDocRoot;
@@ -580,7 +588,7 @@ GWEN_XMLNODE *AB_ImExporterXML_ReadXmlFromSio(AB_IMEXPORTER *ie, GWEN_SYNCIO *si
 
   /* read whole document into XML tree */
   xmlDocRoot=GWEN_XMLNode_new(GWEN_XMLNodeTypeTag, "xmlDocRoot");
-  xmlCtx=GWEN_XmlCtxStore_new(xmlDocRoot, GWEN_XML_FLAGS_HANDLE_COMMENTS | GWEN_XML_FLAGS_HANDLE_HEADERS);
+  xmlCtx=GWEN_XmlCtxStore_new(xmlDocRoot, xmlFlags);
   rv=GWEN_XMLContext_ReadFromIo(xmlCtx, sio);
   if (rv<0) {
     DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
@@ -595,10 +603,20 @@ GWEN_XMLNODE *AB_ImExporterXML_ReadXmlFromSio(AB_IMEXPORTER *ie, GWEN_SYNCIO *si
 
 
 
-int AB_ImExporterXML_ImportDb(AB_IMEXPORTER *ie,
-                              AB_IMEXPORTER_CONTEXT *ctx,
-                              GWEN_DB_NODE *dbData)
+int AB_ImExporterXML_ImportDb(GWEN_UNUSED AB_IMEXPORTER *ie,
+			      AB_IMEXPORTER_CONTEXT *ctx,
+			      GWEN_DB_NODE *dbData)
 {
+
+  _readAccountsFromDb(ctx, dbData);
+  return _readSecuritiesFromDb(ctx, dbData);
+}
+
+
+
+void _readAccountsFromDb(AB_IMEXPORTER_CONTEXT *ctx, GWEN_DB_NODE *dbData)
+{
+
   GWEN_DB_NODE *dbAccount;
 
   dbAccount=GWEN_DB_FindFirstGroup(dbData, "account");
@@ -619,6 +637,10 @@ int AB_ImExporterXML_ImportDb(AB_IMEXPORTER *ie,
                                                          AB_AccountSpec_GetType(accountSpec));
     assert(accountInfo);
 
+    s=AB_ImExporterAccountInfo_GetBankName(accountInfo);
+    if (!(s && *s))
+      AB_ImExporterAccountInfo_SetBankName(accountInfo, AB_AccountSpec_GetBankName(accountSpec));
+
     s=AB_ImExporterAccountInfo_GetCurrency(accountInfo);
     if (!(s && *s)) {
       s=AB_AccountSpec_GetCurrency(accountSpec);
@@ -631,7 +653,7 @@ int AB_ImExporterXML_ImportDb(AB_IMEXPORTER *ie,
     while (dbCurrent) {
       AB_TRANSACTION *t;
 
-      t=dbToTransaction(ie, dbAccount, dbCurrent);
+      t=dbToTransaction(dbAccount, dbCurrent);
       assert(t);
 
       AB_ImExporterAccountInfo_AddTransaction(accountInfo, t);
@@ -653,13 +675,45 @@ int AB_ImExporterXML_ImportDb(AB_IMEXPORTER *ie,
 
     dbAccount=GWEN_DB_FindNextGroup(dbAccount, "account");
   }
+}
+
+
+
+int _readSecuritiesFromDb(AB_IMEXPORTER_CONTEXT *ctx, GWEN_DB_NODE *dbData)
+{
+  GWEN_DB_NODE *dbSecurity;
+
+  dbSecurity=GWEN_DB_FindFirstGroup(dbData, "security");
+  while (dbSecurity) {
+    AB_SECURITY *sec;
+
+    sec=AB_Security_fromDb(dbSecurity);
+    if (sec) {
+      const char *s;
+
+      s=GWEN_DB_GetCharValue(dbSecurity, "unitPriceDate", 0, NULL);
+      if (s && *s) {
+	GWEN_TIME *ti;
+
+	ti=GWEN_Time_fromString(s, "YYYYMMDDhhmmss");
+	if (ti==NULL) {
+	  DBG_ERROR(AQBANKING_LOGDOMAIN, "Bad value for unitPriceDate: %s", s);
+	  return GWEN_ERROR_GENERIC;
+	}
+	AB_Security_SetUnitPriceDate(sec, ti);
+	GWEN_Time_free(ti);
+      }
+      AB_ImExporterContext_AddSecurity(ctx, sec);
+    }
+    dbSecurity=GWEN_DB_FindNextGroup(dbSecurity, "security");
+  }
 
   return 0;
 }
 
 
 
-AB_TRANSACTION *dbToTransaction(AB_IMEXPORTER *ie, GWEN_DB_NODE *dbAccount, GWEN_DB_NODE *dbTransaction)
+AB_TRANSACTION *dbToTransaction(GWEN_DB_NODE *dbAccount, GWEN_DB_NODE *dbTransaction)
 {
   AB_TRANSACTION *t;
   const char *s;
